@@ -22,28 +22,8 @@
 
 
 
-//Include Libraries - Functions - Classes - Prototypes
-#include <stdio.h>
-#include <stdlib.h>
-#include <ctype.h>
-#include <math.h>
-#include <time.h>
+//Include Global Declarations
 #include "headers/gglobal.h"
-#include "headers/gptl.h"
-#include "gsleep.cpp"
-#include "grand.cpp"
-#include "gsocket.cpp"
-#include "gneuron.cpp"
-#include "gerrstat.cpp"
-#include "gerrc.cpp"
-#include "gdmloader.cpp"
-#include "ggendata.cpp"
-#include "greaddata.cpp"
-#include "gsavedata.cpp"
-#include "gremdata.cpp"
-#include "gsnmc.cpp"
-#include "gnms.cpp"
-#include "gumsgs.cpp"
 
 //Main Function
 int main(int argc,char **argv)
