@@ -244,20 +244,6 @@ void GNMS(int SimFunc)
             
             }
             
-            //Print GData
-            printf("----- GData -----\n");
-            
-            for (i=0;i<j;i++)
-            
-            {
-            
-                printf("Minimum Data%i:%.1f\n",i+1,GMinData[i]);
-                printf("Maximum Data%i:%.1f\n",i+1,GMaxData[i]);
-            
-            }
-            
-            printf("-----------------\n\n");
-            
             //Gather Error Statistics (ECT - 0:Uniform,1:Non-Uniform)
             GErr=GErrStat(NewData,GMinData,GMaxData,ECT);
             
