@@ -1,6 +1,6 @@
 /* 
    
-   Geeks Artificial Neural Network (G.A.N.N) - Save Data
+   Geeks Artificial Neural Network (G.A.N.N) - Save Data To GKDB
    
    Copyright GNU/GPL 2005-2006 George Delaportas (qtgeo)
    
@@ -35,23 +35,23 @@ void GSaveData(GNeuron *GMatrix)
     FileToSave=fopen("GKDB","a");
     
     //Set Starting Header
-    fprintf(FileToSave,"%i\n%i\n",MAX_GN,MAX_PIN);
+    fprintf(FileToSave,"%i\n%i\n%i\n%i\n%f\n%i\n%i\n%i\n%i\n",\
+    SimNum,ECT,GMSType,GMCType,Threshold,GNNum,Layers,Inputs,Outputs);
     
-    for (i=0;i<MAX_GN;i++)
+    for (i=0;i<GNNum;i++)
     
     {
     
         fprintf(FileToSave,"%i\n",i+1);
+        fprintf(FileToSave,"%i\n",GMatrix[i].GetInData(i));
+        fprintf(FileToSave,"%i\n",GMatrix[i].GetWeights(i));
         fprintf(FileToSave,"%i\n",GMatrix[i].GetNFT());
-        fprintf(FileToSave,"%f\n",GMatrix[i].OutData());
-        fprintf(FileToSave,"%f\n",GMatrix[i].GetSum());
         fprintf(FileToSave,"%f\n",GMatrix[i].GetBase());
+        fprintf(FileToSave,"%f\n",GMatrix[i].GetSum());
+        fprintf(FileToSave,"%f\n",GMatrix[i].OutData());
     
     }
     
-    //Set Ending Header
-    fprintf(FileToSave,"*\n");
-    
     //Close GKDB
     fclose(FileToSave);
 
