@@ -22,6 +22,13 @@
 
 
 
+//Include Libraries
+#include <stdio.h>
+#include <stdlib.h>
+#include <ctype.h>
+#include <math.h>
+#include <time.h>
+
 //Set Global Symbols Definitions
 #define	   TRUE    1
 #define	   FALSE   0
@@ -46,4 +53,21 @@ int Layers;			//GMap Layers
 int GMap[MAX_LAYERS];		//Bigest GMap
 float Threshold;		//A Threshold Value
 
+//Include Prototypes - Functions - Classes
+#include "gptl.h"
+#include "../gsleep.cpp"
+#include "../grand.cpp"
+#include "../gsocket.cpp"
+#include "../gneuron.cpp"
+#include "../gerrstat.cpp"
+#include "../gerrc.cpp"
+#include "../gdmloader.cpp"
+#include "../ggendata.cpp"
+#include "../greaddata.cpp"
+#include "../gsavedata.cpp"
+#include "../gremdata.cpp"
+#include "../gsnmc.cpp"
+#include "../gnms.cpp"
+#include "../gumsgs.cpp"
+
 /* ------------------------------------------------------------------------ */
